Filtering — SoL 3 user manual

### Navigation

- index
- next |
- previous |
- User manual »
- User interface »
- Basic entities »

# Filtering

The search menu

On the top right of the grid there are two buttons that respectively activate and deactivate record filtering. The former add a row of editable fields just below the column titles where you can insert values that will be used as a filter on the particular column. The latter clears all the current filters.

As shown in the figure, with the menu on the left you can select a different filtering criteria, for example to select players born before a particular date.

It is possible to search on one or more column at the same time, for example to show only french players you can enable the field guilabel:country and type the text `FRA` in its search field, then maybe typing players initials in the field firstname.

### Navigation

- index
- next |
- previous |
- User manual »
- User interface »
- Basic entities »